<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Kliknij, aby wrócić do aplikacji</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Pobrane</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 elementów</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formularz</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nazwa pliku</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Spróbuj ponownie</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zatrzymaj</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publikuj podkast w serwisie Youtube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Tablica</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Sieć Web</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Piórko</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Tła</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Zmień tło</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Wykonaj ponownie</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Wstecz</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Poprzednia strona</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Dalej</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Następna strona</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Zarządzaj dokumentami</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Przeglądanie stron www</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linia</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Mała linia</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Średnia linia</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Duża linia</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Gumka</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Mała gumka</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Średnia gumka</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Duża gumka</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Kolor</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Powrót</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Lewo</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Do przodu</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Prawo</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Ponownie wczytaj</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Ponownie wczytaj bieżącą stronę</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Strona główna</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Wczytaj stronę główną</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Zakładki</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Pokaż zakładki</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Zakładka</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Dodaj zakładkę</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Wyświetl tablicę</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Usuń zawartość</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Preferencje</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Wyświetl preferencje</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Biblioteka</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Pokaż bibliotekę</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Pokaż pulpit</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Pokaż pulpit komputera</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Większy</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Powiększ</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Mniejszy</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Zmniejsz</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nowy folder</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Stwórz nowy folder</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Nowy dokument</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Stwórz nowy dokument</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importuj</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Importuj dokument</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportuj</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Eksportuj dokument</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Otwórz na tablicy</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Otwórz stronę na tablicy</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikuj</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Duplikuj wybraną zawartość</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Usuń wybraną zawartość</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Dodaj do dokumentu roboczego</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Dodaj wybraną zawartość do otwartego dokumentu</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Dodaj zawartość do dokumentu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Zmień nazwę zawartości</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Narzędzia</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Wyświetl narzędzia</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Tryb wieloekranowy</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Rozmiar szeroki (16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Użyj szerokiego rozmiaru dokumentu (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Normalny rozmiar (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Użyj normalnego rozmiaru dokumentu (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Niestandardowy rozmiar</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Użyj niestandardowego rozmiaru dokumentu</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Przerwij wczytywanie</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Przerwij wczytywanie strony internetowej</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Wytnij</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Uśpij</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Uśpij prezentację</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Wirtualna klawiatura</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Wyświetl wirtualną klawiaturę</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Zwykłe jasne tło</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Jasno</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Jasne tło w kratkę</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Zwykłe ciemne tło</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Ciemno</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Ciemne tło w kratkę</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podkast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Nagraj prezentację do filmu</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Nagraj</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Zacznij nagrywanie ekranu</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Usuń elementy</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Usuń wszystkie elementy</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Usuń adnotacje</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Usuń wszystkie adnotacje</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Wyczyść stronę</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Wyczyść wszystkie elementy</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pióro</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Dodaj adnotację do dokumentu</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Usuń adnotację</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marker</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Wyróżnienie </translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Selektor</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Wybierz i zmodyfikuj obiekty</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Ręka</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Przewijaj stronę</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Wskaźnik laserowy</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Wirtualny wskaźnik laserowy</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Rysuj linie</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Napisz tekst</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Przechwyć</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Przechwyć część ekranu</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Dodaj do bieżącej strony</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Dodaj element do bieżącej strony</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Dodaj do nowej strony</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Dodaj element do nowej strony</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Dodaj do biblioteki</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Dodaj element do biblioteki</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Strony</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Stwórz nową stronę</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Nowa strona</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Duplikuj stronę</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Duplikuj bieżącą stronę</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Importuj stronę</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Importuj zewnętrzną stronę</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Wstrzymaj nagrywanie podkastu</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Konfiguracja podkastu</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Konfiguruj nagrywanie podkastu</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation type="vanished">Pułapka Flash</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation type="vanished">Złap zawartość Flash</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Pułapka sieciowa</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Złap zawartość sieci Web</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Niestandardowe przechwycenie</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Przechwycenie okna</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Przechwyć okno</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Osadź zawartość sieci Web</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Przechwyć zawartość sieci Web nadającą się do osadzenia</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Pokaż na wyświetlaczu</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Pokaż główny ekran na wyświetlaczu</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Usuń wszystkie adnotacje</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Importuj symulację eduMedia</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Sprawdź aktualizacje</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation variants="yes">
            <lengthvariant>OpenBoard</lengthvariant>
            <lengthvariant></lengthvariant>
        </translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Zamknij OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Ukryj OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Ukryj aplikację OpenBoard</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Odtwarzaj</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Interakcja z elementami</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Wymaż tło</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Usuń tło</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation>Jasne tło w linie</translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation>Ciemne tło w linie</translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation>Otwórz samouczek</translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation>Otwórz stronę samouczka</translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation>Zresetuj rozmiar kratki</translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation>Mała gumka</translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation>Kolor 1</translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation>Kolor 2</translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation>Kolor 3</translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation>Kolor 4</translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation>Kolor 5</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation>Rysuj drobne linie kratki</translation>
    </message>
    <message>
        <source>Capture Web Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Wymagana autoryzacja</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nazwa użytkownika:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Hasło:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Autoryzacja serwera proxy</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Połącz się z serwerem proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nazwa użytkownika:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Zachowaj nazwę użytkownika i hasło do użytku w przyszłości</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>ID elementu = </translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Zawartość nie jest obsługiwana w formacie docelowym.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Usuń stronę</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Czy na pewno chcesz usunąć 1 stronę z wybranego dokumentu „%0”?</translation>
    </message>
    <message>
        <source>Loading scene (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving cached scenes (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Rozmiar strony</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podkast</translation>
    </message>
    <message>
        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Sieć Web</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Dostępna nowa aktualizacja. Czy chcesz przejść do strony www?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Brak aktualizacji</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Aktualizacja dostępna</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizacja</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation>Rozmiar kratki</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation>Rysuj drobne linie kratki</translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Pobieranie treści %1 zakończone niepowodzeniem</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Pobieranie zakończone</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Nieznany typ narzędzia %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Niaznany typ treści %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Dodaj element</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Wszystkie obsługiwane (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Usuń stronę %1 z dokumentu</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Strona %1 usunięta</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Operacja dodania pliku nieudana: błąd kopiowania pliku</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Grupuj</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Rozgrupuj</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation>Zapisywanie dokumentu...</translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation>Dokument został właśnie zapisany...</translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation>Usuwanie strony %1</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Kolor</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Błąd dodawania obrazu do biblioteki</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>PrzechwyconyObraz</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation>Ładowanie strony (%1/%2)</translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Właściwości pamięci podręcznej</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Kolor:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Kształt:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Rozmiar:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Przechwyć część ekranu</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Przechwyć ekran</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Pokaż paletę piórek</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Pokaż tablicę na ekranie podrzędnym</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Pokaż pulpit na ekranie podrzędnym</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation>Pokaż OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Nowy folder</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Strona %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Dodaj folder z obrazami</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Dodaj obrazy</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Dodaj strony z pliku</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Duplikowanie dokumentu %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Dokument %1 skopiowany</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Usuń stronę</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Usuń dokument</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Czy na pewno chcesz usunąć dokument „%1”?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Opróżnij kosz</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Czy na pewno chcesz opróżnić kosz?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Opróżnianie kosza</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Opróżniono kosz</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Usuń folder</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Czy na pewno chcesz usunąć folder „%1” wraz z zawartością?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Nie wybrano żadnego dokumentu!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Otwórz obsługiwany plik</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importowanie pliku %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Importowanie pliku zakończone niepowodzeniem... </translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Importuj wszystkie obrazy z Foldera</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Opróżnij</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Kosz</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Otwórz dokument</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Dodaj wszystkie obrazy do dokumentu</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Wszystkie obrazy (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>Zaznaczenie nie zawiera żadnych plików obrazów!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Czy na pewno chcesz usunąć %n stronę z wybranego dokumentu „%1”?</numerusform>
            <numerusform>Czy na pewno chcesz usunąć %n strony z wybranego dokumentu „%1”?</numerusform>
            <numerusform>Czy na pewno chcesz usunąć %n stron z wybranego dokumentu „%1”?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>Folder nie zawiera żadnych plików obrazów</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Dokumenty niezatytułowane</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation>
            <numerusform>zduplikowano %1 stronę</numerusform>
            <numerusform>zduplikowano %1 strony</numerusform>
            <numerusform>Zduplikowano %1 stron</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Usuń element</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>Czy na pewno chcesz usunąć zaznaczone elementy?</translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation>Dokument &apos;%1&apos; został utworzony przy użyciu nowszej wersji OpenBoard (%2). Otwierając go możesz stracić niektóre informację. Czy chcesz kontynuować?</translation>
    </message>
    <message>
        <source>Title page</source>
        <translation>Strona tytułowa</translation>
    </message>
    <message>
        <source>Refreshing Document Thumbnails View (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>obrazy</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>filmy</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>obiekty</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widgety</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Wszystkie obsługiwane pliki (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Plik %1 zapisany</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Wstawianie strony %1 z %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importowanie zakończone powodzeniem.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Importowanie pliku %1 zakończone powodzeniem.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Importowanie pliku %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Strona %0</translation>
    </message>
    <message>
        <source>Generating thumbnails for board (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">Eksportowanie zakończone niepowodzeniem.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation>Akceptuj</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Zastąp</translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation>Nazwa %1 jest już używana.
Pozostawienie tej nazwy zastąpi ten dokument.
Zmiana nazwy na nową utworzy nowy dokument.</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation>Kosz</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>Skopiowano %1 stronę</numerusform>
            <numerusform>Skopiowano %1 strony</numerusform>
            <numerusform>Skopiowano %1 stron</numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation>Moje dokumenty</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>Skopiowano %1 stronę</numerusform>
            <numerusform>Skopiowano %1 strony</numerusform>
            <numerusform>Skopiowano %1 stron</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Usuń elementy</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>Czy na pewno chcesz usunąć zaznaczone elementy?</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation>Kopiowanie strony %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (kopia)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Kopiowanie strony %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translatorcomment>The first translation is the singular form</translatorcomment>
        <translation type="vanished">
            <numerusform>Skopiowano %1 stronę</numerusform>
            <numerusform>Skopiowano %1 strony</numerusform>
            <numerusform>Skopiowano %1 stron</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Pobieranie plików</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation>Strona %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation>Strona %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Podczas eksportowania pojawiły się ostrzeżenia</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Eksportowanie dokumentu...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Eksportowanie zakończone powodzeniem.</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Eksportowanie zakończone niepowodzeniem</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation>Nie udało się wyeksportować do wybranej lokacji. Nie masz wystarczających uprawnień do zapisania pliku.</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation>Eksportowanie nie powiodło się: niemożliwy zapis do lokacji</translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Eksportowanie do IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Eksportuj jako plik IWB</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Eksportowanie dokumentu...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Eksportowanie zakończone powodzeniem.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Eksportowanie zakończone niepowodzeniem.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Strona</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Eksportowanie jako plik UBZ</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Eksportowanie dokumentu...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Eksportowanie zakończone powodzeniem.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Eksportowanie %1 %2 z %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation>Wyeksportuj do formatu OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation>Eksportowanie dokumentu...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Eksportowanie zakończone powodzeniem.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Eksportowanie zakończone niepowodzeniem.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation>Nie udało się wyeksportować...</translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation>Wyeksportuj jako plik UBX</translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation>Wyeksportuj jako plik formatu OpenBoard UBX</translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Eksportowanie jako plik PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Eksportowanie dokumentu...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Eksportowanie zakończone powodzeniem.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Eksportowanie do PDF</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Eksportowanie jako plik PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Eksportowanie dokumentu...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Eksportowanie zakończone powodzeniem.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Eksportowanie strony %1 z %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Eksportowanie do PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Strona</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Eksportowanie jako dane sieci Web</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Eksportowanie dokumentu...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Eksportowanie zakończone powodzeniem.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Eksportowanie zakończone niepowodzeniem.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Eksportowanie do przeglądarki sieci Web</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Dodaj do strony</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Ustaw jako tło</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Dodaj do biblioteki</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Informacje o obiekcie</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Dodaj do ulubionych</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Udostępniaj</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Powrót do folderu</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Utwórz nowy folder</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Ponownie skanuj system plików</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>ImportowanyObraz</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Nagrania</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animacje</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interakcje</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Aplikacje</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Kształty</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Wyszukiwanie w sieci</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Kosz</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Akceptuj</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Wpisz nową nazwę folderu</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Wczytywanie </translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Zablokowane</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Widoczne na ekranie rozszerzonym</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Zablokowane</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Widoczne na ekranie rozszerzonym</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Przejdź do źródła zawartości</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation>Ustaw jako tło</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation>Nie udało się znaleźć zasobu multimedialnego</translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation>Niewspierany format zasobu multimedialnego</translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation>Nie znaleziono usługi odtwarzania</translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation>Błąd multimediów: </translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Wpisz tekst tutaj&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Kolor tekstu</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Edytowalne</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Sieć Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Wczytywanie...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Zamrożone</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Przekształć jako narzędzie </translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Wspólny format plików (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importowanie pliku %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Importowanie pliku %1 zakończone niepowodzeniem.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importowanie zakończone powodzeniem.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Importowanie zakończone niepowodzeniem.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Importowanie pliku %1...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importowanie zakończone powodzeniem.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Importowanie pliku %1 zakończone niepowodzeniem.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation>OpenBoard (*.ubz)</translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation>Openboard (zbiór dokumentów) (*.ubx)</translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Format obrazu (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>Importowanie PDF zakończone niepowodzeniem.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Importowanie strony %1 z %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Błąd podczas publikowania filmu w sieci intranet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Publikowanie w sieci intranet w toku %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publikuj</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Podaj nazwę użytkownika i hasło dla „%1” w %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Logowanie do serwera proxy zakończone niepowodzeniem</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>Błędy SSL:

%1

%2

Czy chcesz ignorować te błędy dla tego hosta?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation>Wykryto dokumenty Open-Sankore</translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation>Dokumenty Open-Sankoré są dostępne na twoimkomputerze. Możliwy jest ich import do OpenBoard naciskając przycisk &quot;Kontynuuj&quot; by uruchomić aplikację importującą.</translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation>Pokaż ten panel następnym razem</translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation>Zawsze możesz zyskać dostęp do aplikacji importującej OpenBoard poprzez panel Ustawień w karcie O programie. Uwaga: jeśli zaimportowałaś już dane Open-Sankore, możesz stracić swoje aktualne dokumenty OpenBoard.</translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation>Kontynuuj</translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(kopiuj)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Utrata repozytorium dokumentów</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation>OpenBoard stracił dostęp do repozytorium dokumentów &apos;%1&apos;. Niestety aplikacja musi zostać zamknięta by uniknąć korupcji danych. Ostatnie zmiany również mogą zostać utracone.</translation>
    </message>
    <message>
        <source>Renaming pages (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieving all your documents (found : %1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Angielski</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Rosyjski</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Niemiecki</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francuski</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Francuski (odmiana szwajcarska)</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Uruchomienie dekodera zakończone niepowodzeniem...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Dekoder podkastów niedostępny...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Część %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>na pulpicie...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>w folderze %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podkast utworzony %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Błąd nagrywania podkastu (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Domyślne wejście dźwięku</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Brak nagrań audio</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Mały</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Średni</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Pełny</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publikuj w sieci intranet</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Publikuj w serwisie Youtube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation>OpenBoard Cast</translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>wersja: </translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>Marker jest czuły na nacisk</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Login serwera proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Nazwa użytkownika:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Hasło:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Publikuj dokument w sieci Web</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Tytuł:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Opis:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publikuj</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Moje filmy</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation>Pokaż następnym razem</translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Generowanie miniatur podglądu...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>Wygenerowano %1 miniatur...</translation>
    </message>
    <message>
        <source>Loading thumbnail (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation>Strona %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Maska</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Linijka</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Cyrkiel</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Kątomierz</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Ekierka</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Szkło powiększające</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Pamięć podręczna</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation>Osie</translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Cała strona</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Sieć Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Aktualizator dokumentów</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation> pliki wymagają aktualizacji.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Ścieżka dostępu kopii zapasowej: </translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Przeglądaj</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizacja</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Wybierz folder kopii zapasowej</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Aktualizacja plików zakończona powodzeniem!
Aby uzyskać dostęp do zaktualizowanych dokumentów, należy ponownie uruchomić aplikację.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>W trakcie aktualizacji wystąpił błąd. Pliki nie zostały uszkodzone.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Wyniki aktualizacji plików</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Aktualizowanie pliku </translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Proszę czekać. Proces importowania niedługo się zacznie...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Przypomnij mi później</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Wczytywanie...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>Wywołano %0 (metoda=%1, stan=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Autoryzacja Youtube zakończona niepowodzeniem.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>W trakcie wysyłania filmu do serwisu YouTube (%1) wystąpił błąd</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Wysyłanie do serwisu YouTube w toku %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Samochody i pojazdy</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Zwierzęta</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Sport</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Podróże i wydarzenia</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Gry</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Komedie</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Ludzie i blogi</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Wiadomości i polityka</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Rozrywka</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Edukacja</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Jak to zrobić i style</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Organizacje nienastawione na zysk i aktywizm</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Nauka i technologia</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Zapisz plik</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Pobieranie anulowane: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Błąd podczas otwierania zapisanego pliku: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Błąd zapisywania: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Błąd sieci: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekundy</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuty</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>Zostało - %4 %5</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 z %2 (%3/sek.) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 z %2 - Zatrzymano</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bity</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 pobieranie</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 pobrań</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Wcześniej w dniu dzisiejszym</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 elementów</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>&amp;Nowa zakładka</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Klonuj zakładkę</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zamknij kartę</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Zamknij &amp;Inne karty</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Ponownie wczytaj zakładkę</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Ponownie wczytaj wszystkie zakładki</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Ostatnio zamknięte zakładki</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Bez tytułu)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Brak ostatnio wyszukiwanych</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Ostatnio wyszukiwane</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Wyczyść ostatnio wyszukiwane</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Dodaj do bieżącego dokumentu</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Błąd wczytywania strony: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation>Pobierz dokument PDF: chcesz pobrać plik PDF, czy dodać go do aktualnego dokumentu OpenBoard?</translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Otwórz w nowej zakładce</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation>Przetwarzanie...</translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publikuj Podkast w serwisie Youtube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Słowa kluczowe</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Nazwa użytkownika YouTube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Hasło YouTube</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Klikając „Wyślij”, poświadczasz, że posiadasz wszelkie prawa do zawartości lub masz zezwolenie właściciela zawartości na jej publiczne udostępnianie w serwisie YouTube, a także, że zawartość jest zgodna z Warunkami korzystania z serwisu YouTube dostępnymi pod adresem &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation>Przywróć dane logowania po restarcie</translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>Na jasnym tle</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Na ciemnym tle</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Nieprzezroczystość</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Szerokość linii</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Średnia</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Silna</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Cienka</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Pióro jest czułe na nacisk</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation>Pokaż podgląd pędzla od</translation>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Tytuł</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Opis</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation>Dokumenty OpenBoard</translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation>Data utworzenia</translation>
    </message>
    <message>
        <source>Update date</source>
        <translation>Data modyfikacji</translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation>Porządek alfabetyczny</translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation>Porządek sortowania</translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencje</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>wersja:...</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Ustawienia domyślne</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Wyświetlanie</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Wyświetl stronę w przeglądarce zewnętrznej</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Strona główna:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Wirtualna klawiatura</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Rozmiar przycisków klawiatury:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Pasek narzędzi</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Ustawienie w górnej części (zalecane dla tabletów)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Ustawienie w dolnej części (zalecane dla tablic)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Wyświetlaj tekst pod przyciskiem</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Paleta piórka</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Poziomo</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Pionowo</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pióro</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marker</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informacje o programie</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Aktualizacja oprogramowania</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Sprawdź aktualizacje oprogramowania w trakcie uruchamiania</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licencje</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Pokaż wewnętrzną treść strony na podrzędnym ekranie lub projektorze</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Tryb wielu wyświetlaczy</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Zamień ekran sterowania z ekranem wyświetlania</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Tryb początkowy:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tablica</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Uzytkownik serwera proxy:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Podziękowania</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Na ciemnym tle</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Nieprzezroczystość</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Na jasnym tle</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation>Zamień wyświetlacze</translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation>Rozmiar klawiszy wyświetlanej klawiatury:</translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation>Użyj klawiatury systemowej (zalecane)</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation>Kratka</translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation>Open-Sankoré Importer</translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation>Sprawdź czy dane Open-Sankoré mogą być zaimportowane przy starcie</translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation>Tryb dokumentów</translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation>Wyświetl kolumnę dat w porządku alfabetycznym</translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation>Usuń dokumenty z kosza, które są starsze niż</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dni</translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation>Renderowanie PDF</translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation>Usprawnij wykonywanie przybliżania (może nieco pogorszyć jakość renderowania)</translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Złap Flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation type="vanished">Wybierz Flash do złapania</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Nazwa aplikacji</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Stwórz aplikację</translation>
    </message>
    <message>
        <source>Select a content to capture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
